Learn R Programming

iBreakDown (version 0.9.6)

print.break_down: Print Generic for Break Down Objects

Description

Print Generic for Break Down Objects

Usage

# S3 method for break_down
print(x, ..., digits = 3,
  rounding_function = round)

Arguments

x

the model model of `break_down` class.

...

other parameters.

digits

number of decimal places (round) or significant digits (signif) to be used. See the rounding_function argument.

rounding_function

function that is to used for rounding numbers. It may be signif which keeps a specified number of significant digits. Or the default round to have the same precision for all components.

Value

a data frame

References

Predictive Models: Visual Exploration, Explanation and Debugging https://pbiecek.github.io/PM_VEE